# Table of Contents

- [application-vs-it-component-v3](<./application-vs-it-component-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Application vs. IT component](<./Modeling-Application-vs.-IT-component.md>)
  - [Was this page helpful?](<./Modeling-Application-vs.-IT-component/Was-this-page-helpful.md>)
